orichain.embeddings
===========================

Module contents
---------------

.. automodule:: orichain.embeddings
   :members:
   :undoc-members: 
   :special-members: __init__, __call__
   :exclude-members: model_handler, supported_models
   :show-inheritance:

Submodules
----------

orichain.embeddings.awsbedrock\_embeddings module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.embeddings.awsbedrock_embeddings
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :exclude-members: worker
   :show-inheritance:

orichain.embeddings.azureopenai\_embeddings module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.embeddings.azureopenai_embeddings
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :exclude-members: num_tokens_from_string
   :show-inheritance:

orichain.embeddings.gcp\_gemini\_embeddings module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.embeddings.gcp_gemini_embeddings
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :show-inheritance:

orichain.embeddings.gcp\_vertex\_embeddings module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.embeddings.gcp_vertex_embeddings
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :show-inheritance:

orichain.embeddings.openai\_embeddings module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.embeddings.openai_embeddings
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :exclude-members: num_tokens_from_string
   :show-inheritance:

orichain.embeddings.stransformers\_embeddings module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.embeddings.stransformers_embeddings
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :show-inheritance:
